@@ -4,7 +4,7 @@ env = Environment()
 from flopt.variable import Variable
 from flopt.expression import CustomExpression
 from flopt.problem import Problem
-from flopt.solvers import Solver, Solver_list
+from flopt.solvers import Solver, Solver_list, allAvailableSolvers
 from flopt.solution import Solution
 
 # performance
