@@ -5,7 +5,7 @@ class RandomSearch(SequentialUpdateSearch):
     Random Sampling Search
 
     It is a simple serach, as follows.
-    
+
     .. code-block:: python
 
       def setNewSolution(self, *args, **kwargs):
@@ -16,6 +16,24 @@ class RandomSearch(SequentialUpdateSearch):
         self.name = 'RandomSearch'
         self.can_solve_problems = ['blackbox', 'permutation']
 
+
+    def available(self, prob):
+        """
+        Parameters
+        ----------
+        obj : Expression or VarElement family
+            objective function
+        constraints : list of Constraint
+            constraints
+
+        Returns
+        -------
+        bool
+            return true if it can solve the problem else false
+        """
+        return (not prob.constraints)
+
+
     def setNewSolution(self, *args, **kwargs):
         """
         generate new solution with random.
